nbxmpp.plugin

Package nbxmpp :: Module plugin |
[hide private]
[frames] | no frames]

# Module plugin

source code

Provides PlugIn class functionality to develop extentions for xmpppy

Classes | [hide private]
| PlugIn Abstract xmpppy plugin infrastructure code, providing plugging in/out and debugging functionality

Variables | [hide private]
| log = `logging.getLogger('nbxmpp.plugin')`
| __package__ = ``'``nbxmpp``'``

Imports: logging

Variables Details | [hide private]

  ### log Value:
      logging.getLogger('nbxmpp.plugin')

  ### __package__ Value:
      'nbxmpp'